#include <stdio.h>

int main() {
    printf("Hello, World!\n");
    return 0;
}
#include <stdio.h>

/**
 * The main entry point of the program
 * @return 0 on success
 */
int main(int argc, char **argv) {
    printf("Hello, World!\n");
    return 0;
}

// Helper function
void print_message(const char *message) {
    printf("%s\n", message);
}
